@@ -1,9 +1,10 @@
+# frozen_string_literal: true
 module Capybara
   # @api private
   module Queries
     class TextQuery < BaseQuery
       def initialize(*args)
-        @type = args.shift if args.first.is_a?(Symbol) || args.first.nil?
+        @type = (args.first.is_a?(Symbol) || args.first.nil?) ? args.shift : nil
         @expected_text, @options = args
         unless @expected_text.is_a?(Regexp)
           @expected_text = Capybara::Helpers.normalize_whitespace(@expected_text)
@@ -11,15 +12,6 @@ module Capybara
         @search_regexp = Capybara::Helpers.to_regexp(@expected_text)
         @options ||= {}
         assert_valid_keys
-
-        # this is needed to not break existing tests that may use keys supported by `Query` but not supported by `TextQuery`
-        # can be removed in next minor version (> 2.4)
-        invalid_keys = @options.keys - (COUNT_KEYS + [:wait])
-        unless invalid_keys.empty?
-          invalid_names = invalid_keys.map(&:inspect).join(", ")
-          valid_names = valid_keys.map(&:inspect).join(", ")
-          warn "invalid keys #{invalid_names}, should be one of #{valid_names}"
-        end
       end
 
       def resolve_for(node)
@@ -49,7 +41,7 @@ module Capybara
       private
 
       def valid_keys
-        Capybara::Query::VALID_KEYS # can be changed to COUNT_KEYS + [:wait] in next minor version (> 2.4)
+        COUNT_KEYS + [:wait]
       end
     end
   end
